==> haskell-should-not-typecheck-2.1.0-9-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-should-not-typecheck.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: should-not-typecheck
version: 2.1.0
id: should-not-typecheck-2.1.0-LVFziUvVPHEGwbC9PslcYj
key: should-not-typecheck-2.1.0-LVFziUvVPHEGwbC9PslcYj
license: BSD-3-Clause
maintainer: message.me.on@github.com
author: Callum Rogers
homepage: http://github.com/CRogers/should-not-typecheck
synopsis: A HUnit/hspec assertion library to verify that an expression does not typecheck
description:
    For examples and an introduction to the library please take a look at the <https://github.com/CRogers/should-not-typecheck#should-not-typecheck- README> on github.
category: Testing
abi: 87a05c49d8b6c16066f86e99c9e3c6e0
exposed: True
exposed-modules:
    Test.ShouldNotTypecheck
import-dirs: /usr/lib/ghc-8.4.3/site-local/should-not-typecheck-2.1.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/should-not-typecheck-2.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/should-not-typecheck-2.1.0
hs-libraries: HSshould-not-typecheck-2.1.0-LVFziUvVPHEGwbC9PslcYj
depends:
    base-4.11.1.0 HUnit-1.6.0.0-8OmbxYW4AG9PppbZs26Xx deepseq-1.4.3.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             HUnit-1.6.0.0-8OmbxYW4AG9PppbZs26Xx=6ff9610fd5e59ec310c47074d0590847
             deepseq-1.4.3.0=34da2d42d10eacba0aad99c95b538637
haddock-interfaces: /usr/share/doc/haskell-should-not-typecheck/html/should-not-typecheck.haddock
haddock-html: /usr/share/doc/haskell-should-not-typecheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-should-not-typecheck-2.1.0-10-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-should-not-typecheck.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: should-not-typecheck
version: 2.1.0
id: should-not-typecheck-2.1.0-Gu3817ryCqvHDjbWIVaoNG
key: should-not-typecheck-2.1.0-Gu3817ryCqvHDjbWIVaoNG
license: BSD-3-Clause
maintainer: message.me.on@github.com
author: Callum Rogers
homepage: http://github.com/CRogers/should-not-typecheck
synopsis: A HUnit/hspec assertion library to verify that an expression does not typecheck
description:
    For examples and an introduction to the library please take a look at the <https://github.com/CRogers/should-not-typecheck#should-not-typecheck- README> on github.
category: Testing
abi: 9c95ffca41e2dad97fd980d23ed53df6
exposed: True
exposed-modules:
    Test.ShouldNotTypecheck
import-dirs: /usr/lib/ghc-8.4.3/site-local/should-not-typecheck-2.1.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/should-not-typecheck-2.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/should-not-typecheck-2.1.0
hs-libraries: HSshould-not-typecheck-2.1.0-Gu3817ryCqvHDjbWIVaoNG
depends:
    base-4.11.1.0 HUnit-1.6.0.0-8OmbxYW4AG9PppbZs26Xx deepseq-1.4.3.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             HUnit-1.6.0.0-8OmbxYW4AG9PppbZs26Xx=6ff9610fd5e59ec310c47074d0590847
             deepseq-1.4.3.0=34da2d42d10eacba0aad99c95b538637
haddock-interfaces: /usr/share/doc/haskell-should-not-typecheck/html/should-not-typecheck.haddock
haddock-html: /usr/share/doc/haskell-should-not-typecheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
